@@ -302,6 +302,29 @@ class ClsClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def CreateDashboardSubscribe(self, request):
+        """此接口用于创建仪表盘订阅
+
+        :param request: Request instance for CreateDashboardSubscribe.
+        :type request: :class:`tencentcloud.cls.v20201016.models.CreateDashboardSubscribeRequest`
+        :rtype: :class:`tencentcloud.cls.v20201016.models.CreateDashboardSubscribeResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateDashboardSubscribe", params, headers=headers)
+            response = json.loads(body)
+            model = models.CreateDashboardSubscribeResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def CreateDataTransform(self, request):
         """本接口用于创建数据加工任务。
 
@@ -693,6 +716,29 @@ class ClsClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DeleteDashboardSubscribe(self, request):
+        """此接口用于删除仪表盘订阅
+
+        :param request: Request instance for DeleteDashboardSubscribe.
+        :type request: :class:`tencentcloud.cls.v20201016.models.DeleteDashboardSubscribeRequest`
+        :rtype: :class:`tencentcloud.cls.v20201016.models.DeleteDashboardSubscribeResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DeleteDashboardSubscribe", params, headers=headers)
+            response = json.loads(body)
+            model = models.DeleteDashboardSubscribeResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DeleteDataTransform(self, request):
         """本接口用于删除数据加工任务
 
@@ -1130,6 +1176,29 @@ class ClsClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeDashboardSubscribes(self, request):
+        """本接口用于获取仪表盘订阅列表，支持分页
+
+        :param request: Request instance for DescribeDashboardSubscribes.
+        :type request: :class:`tencentcloud.cls.v20201016.models.DescribeDashboardSubscribesRequest`
+        :rtype: :class:`tencentcloud.cls.v20201016.models.DescribeDashboardSubscribesResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeDashboardSubscribes", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeDashboardSubscribesResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeDashboards(self, request):
         """本接口用于获取仪表盘
 
@@ -1408,7 +1477,7 @@ class ClsClient(AbstractClient):
 
 
     def DescribePartitions(self, request):
-        """本接口用于获取主题分区列表。
+        """该接口已废弃，如需获取分区数量，请使用DescribeTopics接口。
 
         :param request: Request instance for DescribePartitions.
         :type request: :class:`tencentcloud.cls.v20201016.models.DescribePartitionsRequest`
@@ -1546,7 +1615,7 @@ class ClsClient(AbstractClient):
 
 
     def MergePartition(self, request):
-        """本接口用于合并一个读写态的主题分区，合并时指定一个主题分区 ID，日志服务会自动合并范围右相邻的分区。
+        """该接口已废弃，如需修改分区数量，请使用ModifyTopic接口。
 
         :param request: Request instance for MergePartition.
         :type request: :class:`tencentcloud.cls.v20201016.models.MergePartitionRequest`
@@ -1729,6 +1798,29 @@ class ClsClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def ModifyDashboardSubscribe(self, request):
+        """此接口用于修改仪表盘订阅
+
+        :param request: Request instance for ModifyDashboardSubscribe.
+        :type request: :class:`tencentcloud.cls.v20201016.models.ModifyDashboardSubscribeRequest`
+        :rtype: :class:`tencentcloud.cls.v20201016.models.ModifyDashboardSubscribeResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ModifyDashboardSubscribe", params, headers=headers)
+            response = json.loads(body)
+            model = models.ModifyDashboardSubscribeResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def ModifyDataTransform(self, request):
         """本接口用于修改数据加工任务
 
@@ -2074,6 +2166,29 @@ class ClsClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def SearchDashboardSubscribe(self, request):
+        """此接口用于预览仪表盘订阅
+
+        :param request: Request instance for SearchDashboardSubscribe.
+        :type request: :class:`tencentcloud.cls.v20201016.models.SearchDashboardSubscribeRequest`
+        :rtype: :class:`tencentcloud.cls.v20201016.models.SearchDashboardSubscribeResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("SearchDashboardSubscribe", params, headers=headers)
+            response = json.loads(body)
+            model = models.SearchDashboardSubscribeResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def SearchLog(self, request):
         """本接口用于检索分析日志，使用该接口时请注意如下事项：
         1. 该接口除受默认接口请求频率限制外，针对单个日志主题，查询并发数不能超过15。
@@ -2101,7 +2216,7 @@ class ClsClient(AbstractClient):
 
 
     def SplitPartition(self, request):
-        """本接口用于分裂主题分区
+        """该接口已废弃，如需修改分区数量，请使用ModifyTopic接口。
 
         :param request: Request instance for SplitPartition.
         :type request: :class:`tencentcloud.cls.v20201016.models.SplitPartitionRequest`
