@@ -17,6 +17,9 @@
 # CAM签名/鉴权错误。
 AUTHFAILURE = 'AuthFailure'
 
+# 交易流程异常
+FAILEDOPERATION_TRANSACTIONEXCEPTION = 'FailedOperation.TransactionException'
+
 # 内部错误。
 INTERNALERROR = 'InternalError'
 
@@ -50,6 +53,9 @@ INVALIDPARAMETERVALUE = 'InvalidParameterValue'
 # 无法获取到可加速的运营商信息
 INVALIDPARAMETERVALUE_VENDORNOTFOUND = 'InvalidParameterValue.VendorNotFound'
 
+# 超过配额限制。
+LIMITEXCEEDED = 'LimitExceeded'
+
 # 缺少参数错误。
 MISSINGPARAMETER = 'MissingParameter'
 
@@ -74,9 +80,27 @@ OPERATIONDENIED_HARDWAREHASACTIVATED = 'OperationDenied.HardwareHasActivated'
 # 输入SN对应的硬件不存在。
 OPERATIONDENIED_HARDWARENOTEXIST = 'OperationDenied.HardwareNotExist'
 
+# 非法请求，可能是重放攻击、伪造攻击。
+OPERATIONDENIED_ILLEGALREQUEST = 'OperationDenied.IllegalRequest'
+
+# 余额不足
+OPERATIONDENIED_INSUFFICIENTBALANCE = 'OperationDenied.InsufficientBalance'
+
+# 资源包已经变配或续费
+OPERATIONDENIED_MODIFIEDORRENEWED = 'OperationDenied.ModifiedOrRenewed'
+
+# 无支付权限
+OPERATIONDENIED_NOTALLOWEDTOPAY = 'OperationDenied.NotAllowedToPay'
+
 # 请求运营商加速超时。
 OPERATIONDENIED_REQUESTQOSTIMEOUT = 'OperationDenied.RequestQosTimeout'
 
+# 截断开关已经被开启
+OPERATIONDENIED_TRUNCFLAGON = 'OperationDenied.TruncFlagOn'
+
+# 未实名认证
+OPERATIONDENIED_UNAUTHORIZEDUSER = 'OperationDenied.UnauthorizedUser'
+
 # 该用户加速已取消，不处于加速状态。
 OPERATIONDENIED_USERNONACCELERATED = 'OperationDenied.UserNonAccelerated'
 
@@ -95,5 +119,20 @@ OPERATIONDENIED_VENDORSERVERERROR = 'OperationDenied.VendorServerError'
 # 请求的次数超过了频率限制。
 REQUESTLIMITEXCEEDED = 'RequestLimitExceeded'
 
+# 资源被占用。
+RESOURCEINUSE = 'ResourceInUse'
+
+# 资源不存在。
+RESOURCENOTFOUND = 'ResourceNotFound'
+
 # 资源不可用。
 RESOURCEUNAVAILABLE = 'ResourceUnavailable'
+
+# 未授权操作。
+UNAUTHORIZEDOPERATION = 'UnauthorizedOperation'
+
+# 未验证服务权限
+UNAUTHORIZEDOPERATION_NOPERMISSION = 'UnauthorizedOperation.NoPermission'
+
+# 直播服务未开通
+UNAUTHORIZEDOPERATION_UNOPENEDLIVESERVICE = 'UnauthorizedOperation.UnopenedLiveService'
