@@ -256,6 +256,29 @@ class MongodbClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeBackupRules(self, request):
+        """本接口（DescribeBackupRules）用于获取实例自动备份配置信息。
+
+        :param request: Request instance for DescribeBackupRules.
+        :type request: :class:`tencentcloud.mongodb.v20190725.models.DescribeBackupRulesRequest`
+        :rtype: :class:`tencentcloud.mongodb.v20190725.models.DescribeBackupRulesResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeBackupRules", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeBackupRulesResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeClientConnections(self, request):
         """本接口（DescribeClientConnections）用于查询实例客户端连接信息，包括连接 IP 和连接数量。
 
@@ -509,6 +532,52 @@ class MongodbClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeTransparentDataEncryptionStatus(self, request):
+        """获取实例透明加密的开启状态
+
+        :param request: Request instance for DescribeTransparentDataEncryptionStatus.
+        :type request: :class:`tencentcloud.mongodb.v20190725.models.DescribeTransparentDataEncryptionStatusRequest`
+        :rtype: :class:`tencentcloud.mongodb.v20190725.models.DescribeTransparentDataEncryptionStatusResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeTransparentDataEncryptionStatus", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeTransparentDataEncryptionStatusResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def EnableTransparentDataEncryption(self, request):
+        """本接口(EnableTransparentDataEncryption)用于开启云数据库 MongoDB 的透明加密能力。
+
+        :param request: Request instance for EnableTransparentDataEncryption.
+        :type request: :class:`tencentcloud.mongodb.v20190725.models.EnableTransparentDataEncryptionRequest`
+        :rtype: :class:`tencentcloud.mongodb.v20190725.models.EnableTransparentDataEncryptionResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("EnableTransparentDataEncryption", params, headers=headers)
+            response = json.loads(body)
+            model = models.EnableTransparentDataEncryptionResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def FlashBackDBInstance(self, request):
         """该接口用于发起按 Key 闪回任务，依据数据的闪回 Key（默认为 id）对数据进行极速回档，快速恢复业务。
         **说明：按 Key 闪回于2023年09月11日正式进行公测，在此期间，该接口仅对公测用户开放。**
@@ -740,6 +809,29 @@ class MongodbClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def ModifyInstanceParams(self, request):
+        """本接口（ModifyInstanceParams）用于修改mongoDB实例的参数配置。
+
+        :param request: Request instance for ModifyInstanceParams.
+        :type request: :class:`tencentcloud.mongodb.v20190725.models.ModifyInstanceParamsRequest`
+        :rtype: :class:`tencentcloud.mongodb.v20190725.models.ModifyInstanceParamsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ModifyInstanceParams", params, headers=headers)
+            response = json.loads(body)
+            model = models.ModifyInstanceParamsResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def OfflineIsolatedDBInstance(self, request):
         """本接口(OfflineIsolatedDBInstance)用于立即下线隔离状态的云数据库实例。进行操作的实例状态必须为隔离状态。
 
@@ -855,6 +947,29 @@ class MongodbClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def SetBackupRules(self, request):
+        """本接口(SetBackupRules)用于设置 MongoDB 云数据库的自动备份规则。
+
+        :param request: Request instance for SetBackupRules.
+        :type request: :class:`tencentcloud.mongodb.v20190725.models.SetBackupRulesRequest`
+        :rtype: :class:`tencentcloud.mongodb.v20190725.models.SetBackupRulesResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("SetBackupRules", params, headers=headers)
+            response = json.loads(body)
+            model = models.SetBackupRulesResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def SetInstanceMaintenance(self, request):
         """本接口（SetInstanceMaintenance ） 用于设置实例维护时间窗。
 
