@@ -27,7 +27,9 @@ class SmpnClient(AbstractClient):
 
 
     def CreateSmpnEpa(self, request):
-        """企业号码认证
+        """不在使用的API
+
+        企业号码认证
 
         :param request: Request instance for CreateSmpnEpa.
         :type request: :class:`tencentcloud.smpn.v20190822.models.CreateSmpnEpaRequest`
@@ -39,24 +41,20 @@ class SmpnClient(AbstractClient):
             headers = request.headers
             body = self.call("CreateSmpnEpa", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.CreateSmpnEpaResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+            model = models.CreateSmpnEpaResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeSmpnChp(self, request):
-        """查询号码的标记和标记次数
+        """不在使用的API
+
+        查询号码的标记和标记次数
 
         :param request: Request instance for DescribeSmpnChp.
         :type request: :class:`tencentcloud.smpn.v20190822.models.DescribeSmpnChpRequest`
@@ -68,24 +66,20 @@ class SmpnClient(AbstractClient):
             headers = request.headers
             body = self.call("DescribeSmpnChp", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.DescribeSmpnChpResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+            model = models.DescribeSmpnChpResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeSmpnFnr(self, request):
-        """虚假号码识别
+        """不在使用的API
+
+        虚假号码识别
 
         :param request: Request instance for DescribeSmpnFnr.
         :type request: :class:`tencentcloud.smpn.v20190822.models.DescribeSmpnFnrRequest`
@@ -97,24 +91,20 @@ class SmpnClient(AbstractClient):
             headers = request.headers
             body = self.call("DescribeSmpnFnr", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.DescribeSmpnFnrResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+            model = models.DescribeSmpnFnrResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeSmpnMhm(self, request):
-        """号码营销监控
+        """不在使用的API
+
+        号码营销监控
 
         :param request: Request instance for DescribeSmpnMhm.
         :type request: :class:`tencentcloud.smpn.v20190822.models.DescribeSmpnMhmRequest`
@@ -126,24 +116,20 @@ class SmpnClient(AbstractClient):
             headers = request.headers
             body = self.call("DescribeSmpnMhm", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.DescribeSmpnMhmResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+            model = models.DescribeSmpnMhmResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeSmpnMrl(self, request):
-        """查询号码恶意标记等级
+        """不在使用的API
+
+        查询号码恶意标记等级
 
         :param request: Request instance for DescribeSmpnMrl.
         :type request: :class:`tencentcloud.smpn.v20190822.models.DescribeSmpnMrlRequest`
@@ -155,17 +141,11 @@ class SmpnClient(AbstractClient):
             headers = request.headers
             body = self.call("DescribeSmpnMrl", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.DescribeSmpnMrlResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+            model = models.DescribeSmpnMrlResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
\ No newline at end of file
+                raise TencentCloudSDKException(type(e).__name__, str(e))
\ No newline at end of file
